==> svelte-flextable-1.0.6.tgz: package/DataHandler.js <==
/* eslint-disable @typescript-eslint/ban-types */
/* eslint-disable @typescript-eslint/no-explicit-any */
import Context from "./core/Context";
import Rows from "./core/Handlers/Rows";
import Pages from "./core/Handlers/Pages";
import GlobalSearch from "./core/Handlers/GlobalSearch";
import { utils, writeFile } from "xlsx";
import { saveAs } from "file-saver";
export default class DataHandler {
    context;
    rows;
    pages;
    globalSearch;
    i18n;
    constructor(params = { rowsPerPage: null, ajax: null }) {
        this.i18n = this.translate(params.i18n);
        this.context = new Context(params);
        this.rows = new Rows(this.context);
        this.pages = new Pages(this.context);
        this.globalSearch = new GlobalSearch(this.context);
    }
    renderData() {
        return this.context.renderData();
    }
    async getFullList() {
        return this.context.getFullDataToExport();
    }
    async getCurrentList() {
        return this.context.getCurrentDataToExport();
    }
    getLoader() {
        return this.context.isLoading;
    }
    setURL(url, trigger = true) {
        this.context.ajax.url = url;
        if (trigger)
            this.context.triggerMainChange.update((n) => {
                return n + 1;
            });
    }
    getRows() {
        return this.context.rows;
    }
    getRowCount() {
        return this.context.rowCount;
    }
    getRowsPerPage() {
        return this.context.rowsPerPage;
    }
    sort(orderBy) {
        this.setPage(1, false);
        this.rows.sort(orderBy);
    }
    getSorted() {
        return this.context.sorted;
    }
    search(value, scope = null) {
        this.globalSearch.set(value, scope);
    }
    clearSearch() {
        this.globalSearch.remove();
    }
    getPages(params = { ellipsis: false }) {
        if (params.ellipsis) {
            return this.context.pagesWithEllipsis;
        }
        return this.context.pages;
    }
    getPageCount() {
        return this.context.pageCount;
    }
    getPageNumber() {
        return this.context.pageNumber;
    }
    setPage(value, trigger = true) {
        switch (value) {
            case "previous":
                this.pages.previous();
                if (trigger)
                    this.context.triggerMainChange.update((n) => {
                        return n + 1;
                    });
                break;
            case "next":
                this.pages.next();
                if (trigger)
                    this.context.triggerMainChange.update((n) => {
                        return n + 1;
                    });
                break;
            default:
                this.pages.goTo(value);
                if (trigger)
                    this.context.triggerMainChange.update((n) => {
                        return n + 1;
                    });
                break;
        }
    }
    getTriggerChange() {
        return this.context.triggerChange;
    }
    translate(i18n) {
        return {
            ...{
                search: "Search...",
                show: "Show",
                entries: "entries",
                rowCount: "Showing {start} to {end} of {total} entries",
                noRows: "No entries to found",
                previous: "Previous",
                next: "Next",
            },
            ...i18n,
        };
    }
    downloadCSVFile(name, header, data, compression = true) {
        const worksheet = utils.json_to_sheet(this.context.ajax.dataSrc ? data[this.context.ajax.dataSrc] : data.data);
        const workbook = utils.book_new();
        utils.book_append_sheet(workbook, worksheet, name);
        if (header !== null) {
            utils.sheet_add_aoa(worksheet, [header], { origin: "A1" });
        }
        writeFile(workbook, name + ".csv", { compression });
    }
    downloadXLSXFile(name, header, data, compression = true) {
        const worksheet = utils.json_to_sheet(this.context.ajax.dataSrc ? data[this.context.ajax.dataSrc] : data.data);
        const workbook = utils.book_new();
        utils.book_append_sheet(workbook, worksheet, name);
        if (header !== null) {
            utils.sheet_add_aoa(worksheet, [header], { origin: "A1" });
        }
        writeFile(workbook, name + ".xlsx", { compression });
    }
    downloadJSONFile(name, data, type = "text/plain;charset=utf-8") {
        const blob = new Blob([JSON.stringify(this.context.ajax.dataSrc ? data[this.context.ajax.dataSrc] : data.data)], { type });
        saveAs(blob, name + ".json");
    }
}

==> svelte-flextable-1.1.0.tgz: package/DataHandler.js <==
/* eslint-disable @typescript-eslint/ban-types */
/* eslint-disable @typescript-eslint/no-explicit-any */
import Context from "./core/Context";
import Rows from "./core/Handlers/Rows";
import Pages from "./core/Handlers/Pages";
import GlobalSearch from "./core/Handlers/GlobalSearch";
import { utils, writeFile } from "xlsx";
import { saveAs } from "file-saver";
export default class DataHandler {
    context;
    rows;
    pages;
    globalSearch;
    i18n;
    constructor(params = { rowsPerPage: 20, pagination: { type: "offset" }, ajax: { dataSrc: "data", url: null, handler: null } }) {
        if (!params.pagination)
            params.pagination = { type: "offset" };
        this.i18n = this.translate(params.i18n);
        this.context = new Context(params);
        this.rows = new Rows(this.context);
        this.pages = new Pages(this.context);
        this.globalSearch = new GlobalSearch(this.context);
    }
    renderData() {
        return this.context.renderData();
    }
    async getFullList() {
        return this.context.getFullDataToExport();
    }
    async getCurrentList() {
        return this.context.getCurrentDataToExport();
    }
    getPaginationType() {
        return this.context.pagination.type;
    }
    getLoader() {
        return this.context.isLoading;
    }
    setURL(url, trigger = true) {
        this.context.ajax.url = url;
        if (trigger)
            this.context.triggerMainChange.update((n) => {
                return n + 1;
            });
    }
    getRows() {
        return this.context.rows;
    }
    getRowCount() {
        return this.context.rowCount;
    }
    getRowsPerPage() {
        return this.context.rowsPerPage;
    }
    sort(orderBy) {
        if (this.context.pagination.type === "offset") {
            this.setPage(1, false);
        }
        this.rows.sort(orderBy);
    }
    getSorted() {
        return this.context.sorted;
    }
    search(value, scope = null) {
        this.globalSearch.set(value, scope);
    }
    clearSearch() {
        this.globalSearch.remove();
    }
    getPages(params = { ellipsis: false }) {
        if (params.ellipsis) {
            return this.context.pagesWithEllipsis;
        }
        return this.context.pages;
    }
    getPageCount() {
        return this.context.pageCount;
    }
    getPageNumber() {
        return this.context.pageNumber;
    }
    getNextCursor() {
        return this.context.nextCursor;
    }
    getPrevCursor() {
        return this.context.prevCursor;
    }
    setPage(value, trigger = true) {
        switch (value) {
            case "previous":
                this.pages.previous();
                if (trigger)
                    this.context.triggerMainChange.update((n) => {
                        return n + 1;
                    });
                break;
            case "next":
                this.pages.next();
                if (trigger)
                    this.context.triggerMainChange.update((n) => {
                        return n + 1;
                    });
                break;
            case "before":
                this.pages.previous();
                if (trigger)
                    this.context.triggerMainChange.update((n) => {
                        return n + 1;
                    });
                break;
            case "after":
                this.pages.next();
                if (trigger)
                    this.context.triggerMainChange.update((n) => {
                        return n + 1;
                    });
                break;
            default:
                this.pages.goTo(value);
                if (trigger)
                    this.context.triggerMainChange.update((n) => {
                        return n + 1;
                    });
                break;
        }
    }
    getTriggerChange() {
        return this.context.triggerChange;
    }
    translate(i18n) {
        return {
            ...{
                search: "Search...",
                show: "Show",
                entries: "entries",
                rowCount: "Showing {start} to {end} of {total} entries",
                noRows: "No entries to found",
                previous: "Previous",
                next: "Next",
            },
            ...i18n,
        };
    }
    downloadCSVFile(name, header, data, compression = true) {
        const worksheet = utils.json_to_sheet(data[this.context.ajax.dataSrc]);
        const workbook = utils.book_new();
        utils.book_append_sheet(workbook, worksheet, name);
        if (header !== null) {
            utils.sheet_add_aoa(worksheet, [header], { origin: "A1" });
        }
        writeFile(workbook, name + ".csv", { compression });
    }
    downloadXLSXFile(name, header, data, compression = true) {
        const worksheet = utils.json_to_sheet(data[this.context.ajax.dataSrc]);
        const workbook = utils.book_new();
        utils.book_append_sheet(workbook, worksheet, name);
        if (header !== null) {
            utils.sheet_add_aoa(worksheet, [header], { origin: "A1" });
        }
        writeFile(workbook, name + ".xlsx", { compression });
    }
    downloadJSONFile(name, data, type = "text/plain;charset=utf-8") {
        const blob = new Blob([JSON.stringify(data[this.context.ajax.dataSrc])], { type });
        saveAs(blob, name + ".json");
    }
}
